#!/usr/bin/python

# ---------------------------------------------------------------------
# pyfi.py
# A finance library for Python.
# Author: Rupert Scammell (rupe@yak.net), 2001.
# This program is placed in the public domain.
# Version history:
# 1.0 - Initial program
# Advogato: http://www.advogato.com/proj/py-fi
# ----------------------------------------------------------------------

import sys, math

# Simple interest
# Returns: interest value
# Input values:
# See "Simple interest future value" below

def sint(_p,_r,_t):
	_i = _p * _r * _t
	return _i

# Simple interest future value
# Returns:  future value
# Input values:
# _p : principal
# _r : Interest rate (decimal)
# _t : Investment periods

def sint_future_val(_p, _r, _t):
	_fv = _p * (1 + _r * _t)
	return _fv

# Compounded interest
# Returns: Interest value
# Input values:
# _fv : Future value
# _p  : Principal

def cint(_fv, _p):
	_i = _fv - _p
	return _i


# Compound interest future value
# Returns: future value
# Input values:
# _p : principal
# _r : interest rate
# c  : number of compounding periods in a year
# n  : (c * _t) , total number of compounding periods

def cint_future_val(_p, _r, c, n):
	_fv = pow(_p * (1 + (_r / c)), n)
	return _fv


# Annual yield
# Returns: Simple interest rate necessary to yield
# the same amount of dollars yielded by the annual 
# rate _r compounded c times for one year
# Input values:
# _r : interest rate
# _c : number of compounding periods in a year

def ayield(_r, _c):
	yield = pow((1 + (_r / _c)) ,_c) - 1
	return yield


# Ordinary annuity formula
# Returns: future value
# Input values:
# _pymt : payment made during compounding period
# _p : principal
# _r : annual interest rate
# c  : number of compounding periods in a year
# n  : total number of payments

def o_annuity(_pymt, _p, _r, c, n):
	block1 = pow((1+(_r / _c)), n) - 1
	block2 = _r / c
	_fv = _pymt * (block1 / block2)
	return _fv


# Present value of an annuity
# Returns: Lump sum that can be deposited at the beginning of the annuity's term, at
# the same interest rate and with the same compounding period, that would yield the
# same amount as the annuity. 
# Input values:
# See "Ordinary annuity formula" above.

def pval_annuity(_pymt, _r, c, n):
	ipp = _r / c
	pval = _pymt * ((1- pow((1+ipp), -n)) / ipp)
	return pval

# Amortization
# Returns: The amount of money that needs to be paid at the end of each period to
# get rid of the total loan.
# Input values:
# loan : Total loan amount
# _r : annual interest rate
#  c : number of compounding periods a year
#  n : total number of compounding periods

def amort(loan, _r, c, n):
	ipp = _r / c
	amt = (loan * ipp) / (1 - pow((1 + ipp),-n))
	return amt

